==> hibernate-search-engine-4.1.1.Final-redhat-1-sources.jar: org/hibernate/search/cfg/spi/SearchConfigurationBase.java <==
/* 
 * Hibernate, Relational Persistence for Idiomatic Java
 * 
 * JBoss, Home of Professional Open Source
 * Copyright 2012 Red Hat Inc. and/or its affiliates and other contributors
 * as indicated by the @authors tag. All rights reserved.
 * See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This copyrighted material is made available to anyone wishing to use,
 * modify, copy, or redistribute it subject to the terms and conditions
 * of the GNU Lesser General Public License, v. 2.1.
 * This program is distributed in the hope that it will be useful, but WITHOUT A
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
 * PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License,
 * v.2.1 along with this distribution; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA  02110-1301, USA.
 */
package org.hibernate.search.cfg.spi;

import org.hibernate.search.impl.SimpleInitializer;
import org.hibernate.search.spi.InstanceInitializer;


/**
 * Suggested base class to create custom SearchConfiguration implementations.
 * We might need to add new methods to the {@link SearchConfiguration} interface,
 * in that case we can add default implementations here to avoid breaking
 * integration code.
 * 
 * @author Sanne Grinovero <sanne@hibernate.org> (C) 2012 Red Hat Inc.
 */
public abstract class SearchConfigurationBase implements SearchConfiguration {

	/**
	 * Safest to default to true.
	 */
	@Override
	public boolean isTransactionManagerExpected() {
		return true;
	}

	/**
	 * Safest to default to false.
	 */
	@Override
	public boolean isIndexMetadataComplete() {
		return false;
	}

	@Override
	public InstanceInitializer getInstanceInitializer() {
		return SimpleInitializer.INSTANCE;
	}

}

==> hibernate-search-engine-4.6.1.Final-redhat-1-sources.jar: org/hibernate/search/cfg/spi/SearchConfigurationBase.java <==
/*
 * Hibernate, Relational Persistence for Idiomatic Java
 *
 * JBoss, Home of Professional Open Source
 * Copyright 2012 Red Hat Inc. and/or its affiliates and other contributors
 * as indicated by the @authors tag. All rights reserved.
 * See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This copyrighted material is made available to anyone wishing to use,
 * modify, copy, or redistribute it subject to the terms and conditions
 * of the GNU Lesser General Public License, v. 2.1.
 * This program is distributed in the hope that it will be useful, but WITHOUT A
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
 * PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License,
 * v.2.1 along with this distribution; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA  02110-1301, USA.
 */
package org.hibernate.search.cfg.spi;

import org.hibernate.search.impl.DefaultIndexManagerFactory;
import org.hibernate.search.impl.SimpleInitializer;
import org.hibernate.search.spi.InstanceInitializer;


/**
 * Suggested base class to create custom SearchConfiguration implementations.
 * We might need to add new methods to the {@link org.hibernate.search.cfg.spi.SearchConfiguration} interface,
 * in that case we can add default implementations here to avoid breaking
 * integration code.
 *
 * @author Sanne Grinovero <sanne@hibernate.org> (C) 2012 Red Hat Inc.
 */
public abstract class SearchConfigurationBase implements SearchConfiguration {

	/**
	 * Safest to default to true.
	 */
	@Override
	public boolean isTransactionManagerExpected() {
		return true;
	}

	/**
	 * Safest to default to false.
	 */
	@Override
	public boolean isIndexMetadataComplete() {
		return false;
	}

	@Override
	public boolean isDeleteByTermEnforced() {
		return false;
	}

	@Override
	public InstanceInitializer getInstanceInitializer() {
		return SimpleInitializer.INSTANCE;
	}

	@Override
	public boolean isIdProvidedImplicit() {
		return false;
	}

	@Override
	public IndexManagerFactory getIndexManagerFactory() {
		return new DefaultIndexManagerFactory();
	}

}
